# EERILY

timE sERIes pLaYground (EERILY) is a playground for time series.

## A Companion Package for [dl.leima.is](https://dl.leima.is)

EERILY is a package I needed to write about time series forecasting. At the current phase, I am focusing on adding stuff that helps me understanding time series data and some models.


## Development

Make sure to write some tests and check the coverage.

```bash
pytest --cov=. tests/ --cov-report xml:cov.xml
```
